@@ -43,6 +43,7 @@ our @EXPORT = qw(
 	$beta_regex
 	$month_regex
 	$ext_regex
+	@suffixes
 
 	&strchop
 	&emptydir
@@ -54,10 +55,14 @@ our @EXPORT = qw(
 	&checkevenodd
 	&extractfilenames
 	&extractdirectories
+	&extractsuffix
+	&tobasepkgpath
+	&fullpkgpathtoport
 	&info
 	&randstr
 	&arrexists
 	&wantport
+	&primarycategory
 	&uri_filename
 	&uri_lastdir
 	&getdbver
@@ -75,7 +80,7 @@ our @EXPORT = qw(
 
 our %settings;
 
-our (@months, $date_regex, $beta_regex, $month_regex, $ext_regex);
+our (@months, $date_regex, $beta_regex, $month_regex, $ext_regex, @suffixes);
 
 my %beta_types;
 
@@ -94,6 +99,9 @@ my %want_regex = (
 $month_regex = 'Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec';
 $date_regex  = '(?<!\d)\d{4}([\-\.]?)(?:\d{2}|'.$month_regex.')\1\d{2}(?!\d)';
 
+# Sorted by occurences so most likely to hit the first entry
+@suffixes = qw(.tar.gz .tar.bz2 .tar.xz .tgz .gem .zip .tar.Z .tar .tar.lz .tbz .src.tar.gz .shar.gz -src.tar.gz -src.tar.bz2 .war .tbz2 .shar.Z .jar -src.tgz .src.tgz .pdf .gz -tar.Z -src.zip -bin.tar.gz .txi .tcl.gz .tar_1.bz2 .tar.z .tar.lzma .tar.bz2 .src.tar.bz2 .src.tar.Z .shar .sh.Z .sh .run .pl .otf .lzh .gz.sh .exe .Z ..tar.Z -source.zip -source.tar.gz -gpl.tgz -bin.tar.bz2);
+
 %beta_types = (
 	snapshot   => { re => 'svn|cvs|snap(?:shot)?', rank => 1 },
 	unstable   => { re => 'unstable|dev|test',     rank => 2 },
@@ -618,6 +626,13 @@ sub extractdirectories
 	return 1;
 }
 
+sub extractsuffix
+{
+    my ($distname) = shift;
+    foreach my $sufx (@suffixes) {
+	return $sufx if $distname =~ m/$sufx/;
+    }
+}
 
 #------------------------------------------------------------------------------
 # Func: info()
@@ -746,6 +761,34 @@ sub wantport
 	return ($matched == $needed);
 }
 
+sub tobasepkgpath
+{
+    my $fullpkgpath = shift;
+    my $basepkgpath = $fullpkgpath;
+    # Remove any flavors and/or subpackages.
+    $basepkgpath =~ s/,.*//g;
+
+    return $basepkgpath;
+}
+
+sub fullpkgpathtoport
+{
+    my $fullpkgpath = shift;
+    my $port = $fullpkgpath;
+
+    # Remove any categories, flavors and subpackages.
+    $port =~ s/.*\///g;
+    $port =~ s/,.*//g;
+
+    return $port;
+}
+
+sub primarycategory
+{
+    my $categories = shift;
+    my @category = split(/ /, $categories);
+    return @category[0];
+}
 
 #------------------------------------------------------------------------------
 # Func: uri_filename()
@@ -958,8 +1001,7 @@ sub prepare_sql
 			$$sths{$_} = $dbh->prepare($Portroach::SQL::sql{$_})
 				or die DBI->errstr . "; statement \"$_\"";
 		} else {
-			print STDERR "Attempted to prepare non-existent SQL query ($_).\n";
-			return 0;
+			die "Attempted to prepare non-existent SQL query ($_).\n";
 		}
 	}
 
